@@ -39,7 +39,7 @@
 
 typedef jack_default_audio_sample_t sample_t;
 
-static const size_t rb_n_samples = 10000;       /* maximum number of samples to hold in the ring buffer */
+static const size_t rb_n_samples = 53000;       /* maximum number of samples to hold in the ring buffer */
 static uint32_t encoder_packet_magic_number = 'I' << 24 | 'D' << 16 | 'J' << 8 | 'C';
 
 int encoder_init_lame(struct threads_info *ti, struct universal_vars *uv, void *param)
@@ -601,7 +601,7 @@ int encoder_update(struct threads_info *ti, struct universal_vars *uv, void *oth
    return encoder_start(ti, uv, other);
    }
  
-int encoder_new_metadata(struct threads_info *ti, struct universal_vars *uv, void *other)
+int encoder_new_song_metadata(struct threads_info *ti, struct universal_vars *uv, void *other)
    {
    struct encoder *self;
    struct encoder_vars *ev = other;
@@ -609,10 +609,10 @@ int encoder_new_metadata(struct threads_info *ti, struct universal_vars *uv, voi
    if (uv->tab == -1)
       {
       for (uv->tab = 0; uv->tab < ti->n_encoders; uv->tab++)
-         if (!(encoder_new_metadata(ti, uv, other)))
+         if (!(encoder_new_song_metadata(ti, uv, other)))
             return FAILED;
       for (int i = 0; i < ti->n_recorders; i++)
-         if (!(recorder_new_metadata(ti->recorder[i], ev->artist, ev->title)))
+         if (!(recorder_new_metadata(ti->recorder[i], ev->artist, ev->title, ev->album)))
             return FAILED;  
       }
    else
@@ -624,58 +624,58 @@ int encoder_new_metadata(struct threads_info *ti, struct universal_vars *uv, voi
          free(self->artist);
       if (self->title)
          free(self->title);
-      if (self->artist_title)
-         free(self->artist_title);
-      if (self->artist_title_mp3)
-         free(self->artist_title_mp3);
+      if (self->album)
+         free(self->album);
+      if (self->artist_title_lat1)
+         free(self->artist_title_lat1);
       if (ev->artist)
          self->artist = strdup(ev->artist);
       else
          self->artist = strdup("");
+      if (ev->album)
+         self->album = strdup(ev->album);
+      else
+         self->album = strdup("");
       if (ev->title)
          self->title = strdup(ev->title);
       else
          self->title = strdup("");
-      if (ev->artist_title)
-         self->artist_title = strdup(ev->artist_title);
+      if (ev->artist_title_lat1)
+         self->artist_title_lat1 = strdup(ev->artist_title_lat1);
       else
-         self->artist_title = strdup("");
-      if (ev->artist_title_mp3)
-         self->artist_title_mp3 = strdup(ev->artist_title_mp3);
-      else
-         self->artist_title_mp3 = strdup("");
-      if (!(self->artist && self->title && self->artist_title && self->artist_title_mp3))
+         self->artist_title_lat1 = strdup("");
+      if (!(self->artist && self->title && self->album && self->artist_title_lat1))
          {
          pthread_mutex_unlock(&self->metadata_mutex);
          fprintf(stderr, "encoder_new_metadata: malloc failure\n");
          return FAILED;
          }
-      self->new_metadata = TRUE;
+      /* we won't set new_metadata to true here, but wait for custom (per stream) metadata to arrive first */
       pthread_mutex_unlock(&self->metadata_mutex);
       return SUCCEEDED;
       }
    return SUCCEEDED;
    }
 
-int encoder_new_metaformat(struct threads_info *ti, struct universal_vars *uv, void *other)
+int encoder_new_custom_metadata(struct threads_info *ti, struct universal_vars *uv, void *other)
    {
    struct encoder *self = ti->encoder[uv->tab];
    struct encoder_vars *ev = other;
 
    pthread_mutex_lock(&self->metadata_mutex);
    self->new_metadata = FALSE;
-   if (self->metaformat)
-      free(self->metaformat);
-   if (self->metaformat_mp3)
-      free(self->metaformat_mp3);
-   self->metaformat = ev->metaformat;
-   ev->metaformat = NULL;
-   self->metaformat_mp3 = ev->metaformat_mp3;
-   ev->metaformat_mp3 = NULL;
-   if (!self->metaformat)
-      self->metaformat = strdup("");
-   if (!self->metaformat_mp3)
-      self->metaformat_mp3 = strdup("");
+   if (self->custom_meta)
+      free(self->custom_meta);
+   if (self->custom_meta_lat1)
+      free(self->custom_meta_lat1);
+   self->custom_meta = ev->custom_meta;
+   ev->custom_meta = NULL;
+   self->custom_meta_lat1 = ev->custom_meta_lat1;
+   ev->custom_meta_lat1 = NULL;
+   if (!self->custom_meta)
+      self->custom_meta = strdup("");
+   if (!self->custom_meta_lat1)
+      self->custom_meta_lat1 = strdup("");
    self->new_metadata = TRUE;
    pthread_mutex_unlock(&self->metadata_mutex);
    return SUCCEEDED;
@@ -702,10 +702,10 @@ struct encoder *encoder_init(struct threads_info *ti, int numeric_id)
    self->numeric_id = numeric_id;
    self->artist = strdup("");
    self->title = strdup("");
-   self->artist_title = strdup("");
-   self->artist_title_mp3 = strdup("");
-   self->metaformat = strdup("%s");
-   self->metaformat_mp3 = strdup("%s");
+   self->album = strdup("");
+   self->artist_title_lat1 = strdup("");
+   self->custom_meta = strdup("%s");
+   self->custom_meta_lat1 = strdup("%s");
    while ((self->oggserial = rand()) + 20000 < 0 || self->oggserial < 100);
    pthread_mutex_init(&self->mutex, NULL);
    pthread_mutex_init(&self->metadata_mutex, NULL);
@@ -730,18 +730,18 @@ void encoder_destroy(struct encoder *self)
       free(self->rs_input[0]);
    if (self->rs_input[1])
       free(self->rs_input[1]);
-   if (self->metaformat)
-      free(self->metaformat);
-   if (self->metaformat_mp3)
-      free(self->metaformat_mp3);
+   if (self->custom_meta)
+      free(self->custom_meta);
+   if (self->custom_meta_lat1)
+      free(self->custom_meta_lat1);
    if (self->artist)
       free(self->artist);
    if (self->title)
       free(self->title);
-   if (self->artist_title)
-      free(self->artist_title);
-   if (self->artist_title_mp3)
-      free(self->artist_title_mp3);
+   if (self->album)
+      free(self->album);
+   if (self->artist_title_lat1)
+      free(self->artist_title_lat1);
    free(self);
    }
 
