@@ -46,112 +46,49 @@
 #define speex_header_free(h) speex_free(h)
 #endif
 
+static char *prepend(char *before, char *after)
+   {
+   char *new;
+   
+   if (!(new = malloc(strlen(before) + strlen(after) + 1)))
+      {
+      fprintf(stderr, "malloc failure\n");
+      return NULL;
+      }
+      
+   strcpy(new, before);
+   strcat(new, after);
+   free(after);
+   return new;
+   }
+
+#define PREPEND(b, a) a = prepend(b, a); items++; s->metadata_vclen += (4 + strlen(a));
+#define CPREPEND(b, a) if (a && a[0]) { PREPEND(b, a); }
+#define APPEND(a) if (a && a[0]) { writeint(s->metadata_vc, base, (len = strlen(a))); memcpy(s->metadata_vc + base + 4, a, len); base += 4 + len; }
 
 static void live_oggspeex_build_metadata(struct encoder *encoder, struct lose_data *s)
    {
-   char *r, *w, *e, *marker;    /* read, write, end, the placemarker string */
-   int count;   /* the number of occurrences of marker in metaformat */
    int len;
-   size_t size;
    int items = 0;
    int base;
+   struct ogg_tag_data *t = &s->tag_data;
 
-   if (s->artist)
-      free(s->artist);
-   if (s->title)
-      free(s->title);
-   pthread_mutex_lock(&encoder->metadata_mutex);
-   for (count = 0, r = encoder->metaformat; (r = strstr(r, "%s")); count++, r += 2);
-   if (count == 0)
+   /* build a vorbis comment block */
+   s->metadata_vclen = 8 + s->vs_len;
+   live_ogg_capture_metadata(encoder, t);
+
+   if (t->custom && t->custom[0])
       {
-      /* handle metadata does not contain artist - title */
-      s->artist = NULL;
-      if (encoder->metaformat && encoder->metaformat[0] != '\0')
-         {
-         if (!(s->title = malloc(strlen(encoder->metaformat) + 7)))
-            {
-            fprintf(stderr, "live_oggspeex_build_metadata: malloc failure\n");
-            return;
-            }
-         sprintf(s->title, "TITLE=%s", encoder->metaformat);
-         }
-      else
-         s->title = NULL;
+      PREPEND("title=", t->custom)
+      CPREPEND("trk-author=", t->artist)
+      CPREPEND("trk-title=", t->title)
+      CPREPEND("trk-album=", t->album)
       }
    else
       {
-      /* handle metadata only contains artist - title */
-      if (count == 1 && !strcmp(encoder->metaformat, "%s"))
-         {
-         if (encoder->artist && encoder->artist[0] != '\0')
-            {
-            if (!(s->artist = malloc(strlen(encoder->artist) + 8)))
-               {
-               fprintf(stderr, "live_oggspeex_build_metadata: malloc failure\n");
-               return;
-               }
-            sprintf(s->artist, "author=%s", encoder->artist);
-            }
-         else
-            s->artist = NULL;
-         if (encoder->title && encoder->title[0] != '\0')
-            {
-            if (!(s->title = malloc(strlen(encoder->title) + 7)))
-               {
-               fprintf(stderr, "live_oggspeex_build_metadata: malloc failure\n");
-               return;
-               }
-            sprintf(s->title, "title=%s", encoder->title);
-            }
-         else
-            s->title = NULL;
-         }
-      else
-         {
-         /* handle a mix of possible multiple "artist - title" and or other text */
-         /* in python: artist = metaformat.replace("%s", artist_title) */
-         /* in C see below LOL */
-         s->title = malloc(size = count * strlen(encoder->artist_title) + strlen(encoder->metaformat) - count * strlen(marker = "%s") + 7);
-         if (!s->title)
-            fprintf(stderr, "live_oggspeex_build_metadata: malloc failure\n");
-         else
-            {
-            strcpy(s->title, "TITLE=");
-            len = strlen(encoder->artist_title);
-            r = encoder->metaformat;
-            w = s->title + 6;
-            for (;;)
-               {
-               if ((e = strstr(r, marker)))
-                  {
-                  memcpy(w, r, e - r);  /* copy the text before the %s */
-                  w += e - r;           /* advance write pointer */
-                  memcpy(w, encoder->artist_title, len); /* copy artist - title */
-                  w += len;             /* advance the write pointer */
-                  r = e + 2;            /* skip over the %s */
-                  }
-               else
-                  {
-                  strcpy(w, r); /* copy the remaining text and null terminate */
-                  break;        /* finished */
-                  }
-               }
-            }
-         s->artist = NULL;
-         }
-      }
-   
-   s->metadata_vclen = 8 + s->vs_len;
-   if (s->artist)
-      {
-      items++;
-      s->metadata_vclen += 4 + strlen(s->artist);
-      }
-      
-   if (s->title)
-      {
-      items++;
-      s->metadata_vclen += 4 + strlen(s->title);
+      CPREPEND("author=", t->artist)
+      CPREPEND("title=", t->title)
+      CPREPEND("album=", t->album)
       }
       
    if (!(s->metadata_vc = realloc(s->metadata_vc, s->metadata_vclen)))
@@ -166,28 +103,15 @@ static void live_oggspeex_build_metadata(struct encoder *encoder, struct lose_da
    writeint(s->metadata_vc, 4 + s->vs_len, items);
    base = 8 + s->vs_len;
    
-   if (s->artist)
-      {
-      writeint(s->metadata_vc, base, (len = strlen(s->artist)));
-      memcpy(s->metadata_vc + base + 4, s->artist, len);
-      base += 4 + len;
-      }
-   
-   if (s->title)
-      {
-      writeint(s->metadata_vc, base, (len = strlen(s->title)));
-      memcpy(s->metadata_vc + base + 4, s->title, len);
-      base += 4 + len;
-      }
+   APPEND(t->custom);
+   APPEND(t->artist);
+   APPEND(t->title);
+   APPEND(t->album);
    
    if (base != s->metadata_vclen)
-      fprintf(stderr, "live_oggspeex_build_metadata: incorrect size assumption }}}}}}\n");
+      fprintf(stderr, "live_oggspeex_build_metadata: incorrect size assumption %d, %d\n", base, s->metadata_vclen);
    else
       fprintf(stderr, "vorbis comment created successfully\n");
-   
-   
-   pthread_mutex_unlock(&encoder->metadata_mutex);
-   fprintf(stderr, "live_oggspeex_build_metadata: metadata for encoder %d\n%s\n%s\n", encoder->numeric_id, s->artist, s->title);
    }
 
 static void live_oggspeex_encoder_monomix(float *in, float *out, size_t n)
@@ -438,10 +362,7 @@ static void live_oggspeex_encoder_main(struct encoder *encoder)
       free(s->inbuf);
    if (s->metadata_vc)
       free(s->metadata_vc);
-   if (s->artist)
-      free(s->artist);
-   if (s->title)
-      free(s->title);
+   live_ogg_free_metadata(&s->tag_data);
    free(s);
    fprintf(stderr, "live_oggspeex_encoder_main: finished cleanup\n");
    return;
