@@ -17,6 +17,7 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <jack/jack.h>
 #include "agc.h"
 
 struct mic
@@ -31,29 +32,40 @@ struct mic
    float lcm;       /* audio left channel with muting */
    float rcm;       /* audio right channel with muting */
    
-   /* inputs */
+   /* control inputs */
    int open;        /* mic open/close */
    int invert;      /* mic signal is inverted */
    float gain;      /* amount of signal boost in db */
-   int complexity;  /* level of processing of lc, rc */
+   int mode;        /* 0 = off, 1 = simple, 2 = complex, 3 = subordinate */
    int pan;         /* stereo panning on a scale 1-100 */
    int pan_active;  /* whether to pan at all */
+   int mode_request;/* request to change mode */
    
    /* state variables and resources */
-   int active;      /* microphone is enabled */
-   struct agc *agc; /* automatic gain control */
+   int id;          /* numeric identifier */
+   struct mic *host;/* the dominant mic in a pairing */
+   struct mic *partner; /* the partnerable mic */
+   struct agc *agc; /* automatic gain control and much more */
+   float sample;    /* storage for the audio sample undergoing processing */
    float sample_rate; /* used for smoothed mute timing */
-   float mgain;    /* mono gain value */
-   float lgain;   /* left gain value */
-   float rgain;   /* right gain value */
+   float mgain;   /* mono gain value (absolute gain) */
+   float lgain;   /* left gain value (pan relative) */
+   float rgain;   /* right gain value (pan relative) */
+   float igain;   /* inversion gain value (inversion relative) */
    float mute;    /* gain applied by soft mute control */
    float djmute;  /* gain applied for muting from the dj mix */
    float peak;    /* highest signal level since last call to mic_getpeak */
+   float rel_igain; /* invert for paired mic */
+   float rel_gain;  /* signal level trim for paired mic */
+   jack_port_t *jack_port; /* jack port handle */
+   jack_default_audio_sample_t *jadp; /* jack audio data pointer */
+   jack_nframes_t nframes; /* jack buffer size */
+   char *default_mapped_port_name; /* the natural partner port or NULL*/
    };
 
-void mic_process(struct mic *self, float input);
-void mic_stats(char *key, struct mic *self);
-struct mic *mic_init(int sample_rate);
-void mic_free(struct mic *self);
+void mic_process_start_all(struct mic **mics, jack_nframes_t nframes);
+float mic_process_all(struct mic **mics);
+void mic_stats_all(struct mic **mics);
+struct mic **mic_init_all(int n_mics, jack_client_t *client);
+void mic_free_all(struct mic **self);
 void mic_valueparse(struct mic *s, char *param);
-
