@@ -143,8 +143,19 @@ static int vorbis_get_samplerate(struct oggdec_vars *self)  /* attempt to get AR
       samplerate = self->samplerate[self->ix] = vi.rate;
       self->channels[self->ix] = vi.channels;
       
-      obtain_tag_info("artist", &self->artist[self->ix], TRUE);
-      obtain_tag_info("title", &self->title[self->ix], TRUE);
+      if (vorbis_comment_query_count(&vc, "trk-title"))
+         {
+         obtain_tag_info("trk-artist", &self->artist[self->ix], TRUE);
+         obtain_tag_info("trk-title", &self->title[self->ix], TRUE);
+         obtain_tag_info("trk-album", &self->album[self->ix], TRUE);
+         }
+      else
+         {
+         obtain_tag_info("artist", &self->artist[self->ix], TRUE);
+         obtain_tag_info("title", &self->title[self->ix], TRUE);
+         obtain_tag_info("album", &self->album[self->ix], TRUE);
+         }
+     
       obtain_tag_info("replaygain_track_gain", &self->replaygain[self->ix], FALSE);
       }
    else
@@ -271,7 +282,7 @@ static void oggflac_metadata_callback(const FLAC__StreamDecoder *decoder, const
    struct oggdec_vars *self = client_data;
    const FLAC__StreamMetadata_StreamInfo *si;
    const FLAC__StreamMetadata_VorbisComment *vc;
-   int i;
+   int i, use_alt_tags;
    
    int match(char *t, char *comment)
       {
@@ -324,11 +335,26 @@ static void oggflac_metadata_callback(const FLAC__StreamDecoder *decoder, const
          fprintf(stderr, "oggflac_metadata_callback: got vorbis comment metadata block\n");
          vc = &metadata->data.vorbis_comment;
          fprintf(stderr, "There are %u comment tags\n", (unsigned)vc->num_comments);
+         use_alt_tags = FALSE;
          for (i = 0; i < vc->num_comments; i++)
+            {
+            if (match("trk-title", (char *)vc->comments[i].entry))
+               use_alt_tags = TRUE;
             fprintf(stderr, "%s\n", vc->comments[i].entry);
+            }
 
-         copy_tag("artist=", &self->artist[self->ix], TRUE);
-         copy_tag("title=", &self->title[self->ix], TRUE);
+         if (use_alt_tags)
+            {
+            copy_tag("trk-artist=", &self->artist[self->ix], TRUE);
+            copy_tag("trk-title=", &self->title[self->ix], TRUE);
+            copy_tag("trk-album=", &self->album[self->ix], TRUE);
+            }
+         else
+            {
+            copy_tag("artist=", &self->artist[self->ix], TRUE);
+            copy_tag("title=", &self->title[self->ix], TRUE);
+            copy_tag("album=", &self->album[self->ix], TRUE);
+            }
          copy_tag("replaygain_track_gain=", &self->replaygain[self->ix], FALSE);
          }
       else
@@ -398,12 +424,72 @@ static int flac_get_samplerate(struct oggdec_vars *self)
 
 #ifdef HAVE_SPEEX
 
+static int speex_comment_count(char *comments, int length, char *match_string)
+   {
+   char *c=comments;
+   int len, i, nb_fields, count = 0;
+   char *end;
+
+   if (length < 8)
+      {
+      fprintf (stderr, "Invalid/corrupted comments\n");
+      return -1;
+      }
+   
+   end = c + length;
+   len = readint(c, 0);
+   c += 4;
+   
+   if (c + len > end)
+      {
+      fprintf (stderr, "Invalid/corrupted comments\n");
+      return -1;
+      }
+
+   c += len;
+   if (c + 4 > end)
+      {
+      fprintf (stderr, "Invalid/corrupted comments\n");
+      return -1;
+      }
+
+   nb_fields = readint(c, 0);
+   c += 4;
+   for (i = 0; i < nb_fields; i++)
+      {
+      if (c + 4 > end)
+         {
+         fprintf (stderr, "Invalid/corrupted comments\n");
+         return -1;
+         }
+      
+      len = readint(c, 0);
+      c += 4;
+      if (c + len > end)
+         {
+         fprintf (stderr, "Invalid/corrupted comments\n");
+         return -1;
+         }
+      
+      if (!strncasecmp(c, match_string, strlen(match_string)))
+         count += 1;
+      c += len;
+      }
+   return count;
+   }
+
 static void speex_get_comments(struct oggdec_vars *self, char *comments, int length)
    {
    char *c=comments;
-   int len, i, nb_fields;
+   int len, i, nb_fields, use_alt;
    char *end;
 
+   use_alt = speex_comment_count(comments, length, "trk-title") ? TRUE : FALSE;
+   if (use_alt)
+      fprintf(stderr, "using alternative speex tags\n");
+   else
+      fprintf(stderr, "using regular speex tags\n");
+
    void handle_keyval(char *key, char *val, char **target, char *match, int multiple)
       {
       char *old;
@@ -427,7 +513,6 @@ static void speex_get_comments(struct oggdec_vars *self, char *comments, int len
   
    void handle_comment(char *comment, int comment_length)
       {
-      
       char *key = malloc(comment_length + 1);
       char *val;
       
@@ -442,15 +527,27 @@ static void speex_get_comments(struct oggdec_vars *self, char *comments, int len
          }
       *val++ = '\0';
 
-      handle_keyval(key, val, &self->artist[self->ix], "author", TRUE);
-      handle_keyval(key, val, &self->artist[self->ix], "artist", TRUE);
-      handle_keyval(key, val, &self->title[self->ix], "title", TRUE);
+      if (use_alt)
+         {
+         handle_keyval(key, val, &self->artist[self->ix], "trk-author", TRUE);
+         handle_keyval(key, val, &self->artist[self->ix], "trk-artist", TRUE);
+         handle_keyval(key, val, &self->title[self->ix], "trk-title", TRUE);
+         handle_keyval(key, val, &self->album[self->ix], "trk-album", TRUE);
+         }
+      else
+         {
+         handle_keyval(key, val, &self->artist[self->ix], "author", TRUE);
+         handle_keyval(key, val, &self->artist[self->ix], "artist", TRUE);
+         handle_keyval(key, val, &self->title[self->ix], "title", TRUE);
+         handle_keyval(key, val, &self->album[self->ix], "album", TRUE);
+         }
       handle_keyval(key, val, &self->replaygain[self->ix], "replaygain_track_gain", FALSE);
       free(key);
       }
    
    self->artist[self->ix] = NULL;
    self->title[self->ix] = NULL;
+   self->album[self->ix] = NULL;
    
    if (length < 8)
       {
@@ -501,6 +598,8 @@ static void speex_get_comments(struct oggdec_vars *self, char *comments, int len
       self->artist[self->ix] = strdup("");
    if (self->title[self->ix] == NULL)
       self->title[self->ix] = strdup("");
+   if (self->album[self->ix] == NULL)
+      self->album[self->ix] = strdup("");
    }
 
 static int speex_get_samplerate(struct oggdec_vars *self)
@@ -600,6 +699,8 @@ static off_t oggscan_eos(struct oggdec_vars *self, off_t offset, off_t offset_en
          self->artist[self->n_streams - 1] = strdup("");
          self->title  = realloc(self->title,  self->n_streams * sizeof (char *));
          self->title[self->n_streams - 1] = strdup("");
+         self->album  = realloc(self->album,  self->n_streams * sizeof (char *));
+         self->album[self->n_streams - 1] = strdup("");
          self->replaygain = realloc(self->replaygain, self->n_streams * sizeof (char *));
          self->replaygain[self->n_streams - 1] = strdup("");
          self->streamtype = realloc(self->streamtype, self->n_streams * sizeof (enum streamtype_t));
@@ -809,12 +910,13 @@ static struct oggdec_vars *oggdecode_get_metadata(char *pathname)
          "serial number    %d\n"
          "artist           %s\n"
          "title            %s\n"
+         "album            %s\n"
          "samplerate       %d\n"
          "channels         %d\n"
          "start time (s)   %lf\n"
          "duration (s)     %lf\n",
          (int)self->bos_offset[i], self->granule_count[i],
-         self->serial[i], self->artist[i], self->title[i], samplerate,
+         self->serial[i], self->artist[i], self->title[i], self->album[i], samplerate,
          self->channels[i], self->start_time[i], self->duration[i]);
 #endif
       }
@@ -837,6 +939,8 @@ static void oggdecode_free_metadata(struct oggdec_vars *self)
             free(self->artist[i]);
          if (self->title[i])
             free(self->title[i]);
+         if (self->album[i])
+            free(self->album[i]);
          }
          
       free(self->bos_offset);
@@ -844,6 +948,7 @@ static void oggdecode_free_metadata(struct oggdec_vars *self)
       free(self->serial);
       free(self->artist);
       free(self->title);
+      free(self->album);
       free(self->streamtype);
       free(self->start_time);
       free(self->duration);
@@ -952,16 +1057,13 @@ void oggdecode_dynamic_dispatcher(struct xlplayer *xlplayer)
          else
             delay = 0;
          
-         if (s->artist[s->ix][0] && s->title[s->ix][0])
-            xlplayer_set_dynamic_metadata(xlplayer, DM_SPLIT_U8, s->artist[s->ix], s->title[s->ix], "", delay);
+         if (s->artist[s->ix][0] || s->title[s->ix][0])
+            xlplayer_set_dynamic_metadata(xlplayer, DM_SPLIT_U8, s->artist[s->ix], s->title[s->ix], s->album[s->ix], delay);
          else
-            if (s->title[s->ix][0])
-               xlplayer_set_dynamic_metadata(xlplayer, DM_JOINED_U8, "", "", s->title[s->ix], delay);
-            else
-               {
-               fprintf(stderr, "oggdecode_dynamic_dispatcher: insufficient metadata\n");
-               xlplayer_set_dynamic_metadata(xlplayer, DM_NOTAG, "", "", "", delay);
-               }
+            {
+            fprintf(stderr, "oggdecode_dynamic_dispatcher: insufficient metadata\n");
+            xlplayer_set_dynamic_metadata(xlplayer, DM_NOTAG, "", "", "", delay);
+            }
          
          xlplayer->usedelay = TRUE;
          return;
@@ -1049,7 +1151,7 @@ int oggdecode_reg(struct xlplayer *xlplayer)
       }
    }
 
-int oggdecode_get_metainfo(char *pathname, char **artist, char **title, double *length, char **replaygain)
+int oggdecode_get_metainfo(char *pathname, char **artist, char **title, char **album, double *length, char **replaygain)
    {
    struct oggdec_vars *self;
    int has_pbtime;
@@ -1068,7 +1170,8 @@ int oggdecode_get_metainfo(char *pathname, char **artist, char **title, double *
           * possess a metaheader */
          *artist = realloc(*artist, 1);
          *title  = realloc(*title, 1);
-         *artist[0] = *title[0] = '\0';
+         *album  = realloc(*album, 1);
+         *artist[0] = *title[0] = *album[0] = '\0';
          }
       else
          {
@@ -1096,6 +1199,18 @@ int oggdecode_get_metainfo(char *pathname, char **artist, char **title, double *
             *title[0] = '\0';
             }
 
+         if (self->album[0])
+            { 
+            if (*album)
+               free(*album);
+            *album = strdup(self->album[0]);
+            }
+         else
+            {
+            *album = realloc(*album, 1);
+            *album[0] = '\0';
+            }
+
          if (self->replaygain[0])
             {
             if (*replaygain)
