@@ -39,7 +39,9 @@ struct recorder_vars
  * compression ratio to provide for the creation of a seek table in the Xing tag */
 struct metadata_item
    {
-   char *artist_title;
+   char *artist;
+   char *title;
+   char *album;
    int time_offset;
    int byte_offset;
    int time_offset_end;
@@ -104,6 +106,7 @@ struct recorder
    FILE *fpcue;
    char *artist;
    char *title;
+   char *album;
    int artist_title_writes;
    pthread_mutex_t artist_title_mutex;
    int new_artist_title;
@@ -116,6 +119,6 @@ int recorder_stop(struct threads_info *ti, struct universal_vars *uv, void *othe
 int recorder_pause(struct threads_info *ti, struct universal_vars *uv, void *other);
 int recorder_unpause(struct threads_info *ti, struct universal_vars *uv, void *other);
 int recorder_make_report(struct recorder *self);
-int recorder_new_metadata(struct recorder *self, char *artist, char *title);
+int recorder_new_metadata(struct recorder *self, char *artist, char *title, char *album);
 
 #endif
