@@ -212,12 +212,12 @@ int main()
       { "speex_complexity", &ev.speex_complexity },
       { "filename",         &ev.filename },
       { "offset",           &ev.offset },
-      { "metaformat",       &ev.metaformat },
-      { "metaformat_mp3",   &ev.metaformat_mp3 },
+      { "custom_meta",      &ev.custom_meta },
+      { "custom_meta_lat1", &ev.custom_meta_lat1 },
       { "artist",           &ev.artist },
       { "title",            &ev.title },
-      { "artist_title",     &ev.artist_title },
-      { "artist_title_mp3", &ev.artist_title_mp3 },
+      { "album",            &ev.album },
+      { "artist_title_lat1", &ev.artist_title_lat1 },
       { "freeformat_mp3",   &ev.freeformat_mp3 },
       { "stream_source",    &sv.stream_source },        /* streamer_vars */
       { "server_type",      &sv.server_type },
@@ -253,8 +253,8 @@ int main()
       { "encoder_stop", encoder_stop, NULL },
       { "encoder_update", encoder_update, &ev },
       { "test_ogg_values", live_ogg_test_values, &ev },
-      { "new_metadata", encoder_new_metadata, &ev },
-      { "new_metaformat", encoder_new_metaformat, &ev },
+      { "new_song_metadata", encoder_new_song_metadata, &ev },
+      { "new_custom_metadata", encoder_new_custom_metadata, &ev },
       { "recorder_start", recorder_start, &rv },
       { "recorder_stop", recorder_stop, NULL },
       { "recorder_pause", recorder_pause, &rv },
