@@ -548,7 +548,7 @@ struct xlplayer *xlplayer_create(int samplerate, double duration, char *playerna
    self->dynamic_metadata.data_type = DM_NONE_NEW;
    self->dynamic_metadata.artist = NULL;
    self->dynamic_metadata.title = NULL;
-   self->dynamic_metadata.artist_title = NULL;
+   self->dynamic_metadata.album = NULL;
    self->dynamic_metadata.current_audio_context = 0;
    self->dynamic_metadata.rbdelay = 0;
    pthread_create(&self->thread, NULL, (void *(*)(void *)) xlplayer_main, self);
@@ -857,7 +857,7 @@ int xlplayer_calc_rbdelay(struct xlplayer *xlplayer)
    return jack_ringbuffer_read_space(xlplayer->left_ch) * 1000 / (sizeof (sample_t) * xlplayer->samplerate);
    }
 
-void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *artist_title, int delay)
+void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t type, char *artist, char *title, char *album, int delay)
    {
    struct xlp_dynamic_metadata *dm = &(xlplayer->dynamic_metadata);
    
@@ -867,11 +867,11 @@ void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t ty
       free(dm->artist);
    if (dm->title)
       free(dm->title);
-   if (dm->artist_title)
-      free(dm->artist_title);
+   if (dm->album)
+      free(dm->album);
    dm->artist = strdup(artist);
    dm->title = strdup(title);
-   dm->artist_title = strdup(artist_title);
+   dm->album = strdup(album);
    dm->current_audio_context = xlplayer->current_audio_context;
    dm->rbdelay = delay;
    pthread_mutex_unlock(&(dm->meta_mutex));
