@@ -32,12 +32,14 @@ allowed_commands = ( "--play",
                      "--request_right",
                      "--testmonitor_on",
                      "--testmonitor_off",
+                     "--record_start",
+                     "--record_stop",
                      "--update" )
 
 def usage():
    print "commands are:", allowed_commands
    print "usage: idjcctrl [--play] [--enqueue] file1.mp3 file2.m3u"
-   print "or     idjcctrl [--connect] 1 2 3"
+   print "or     idjcctrl [--connect] [--record_start] 1 2"
    sys.exit(5)
 
 def write_out_file(command, listoffiles):
