@@ -106,9 +106,9 @@ all = "All"
 
 alternate = "Alternate"
 
-alt_mic_name = "Extra open button text goes here e.g. DJ or Guest, to appear in the main window."
+alt_mic_name = "Alternate opener button text goes here e.g. DJ or Guest. When not specified the microphone number is used instead."
 
-announce_tip = "Enter the message you want to send here. To include the track currently playing use %s. You can also include colours using Ctrl+K (standard XChat/mIRC method) or from the context menu (right click)."
+announce_tip = "Enter the message you want to send here. Use %r, %t, %l for artist, title, album metadata. You can also include colours using Ctrl+K (standard XChat/mIRC method) or from the context menu (right click)."
 
 announcement_countdown_label = "(mm:ss)   "
 
@@ -244,7 +244,7 @@ conn_col_mount = "Mount point      "
 
 conn_col_listeners = "Listeners"
 
-connect_disconnect_nonconfig = "Server Not Configured"
+connect_disconnect_nonconfig = "No Master Server Configured"
 
 connected_to_history = "connected to"
 
@@ -280,7 +280,9 @@ cross_left_tip = "Move the crossfader fully left."
 
 cross_middle_tip = "Move the crossfader to the middle of its range of travel."
 
-cross_pattern_tip = "This changes the response curve of the crossfader."
+cross_pattern_tip = """This selects the response curve of the crossfader.
+
+The mid-point attenuations are -3dB, 0dB, and -22dB respectively."""
 
 cross_right_tip = "Move the crossfader fully right."
 
@@ -452,6 +454,8 @@ external_directory = "Choose a folder/directory of music."
 
 extra_info = "Stream Info"
 
+fadeover = "Fade Over"
+
 fade_none_menu = "No Fade"
 
 fade_5_menu = "Fade 5s"
@@ -490,6 +494,10 @@ flacmetadata = "Metadata"
 
 flacmetadata_tip = "You can prevent the sending of metadata by turning this feature off. This will prevent certain players from dropping the stream or inserting an audible gap every time the song title changes."
 
+flash_mic_button = "Microphone reminder - flashes the mic button icon"
+
+flash_mic_button_tip = "A reminder to turn the microphone off when a main player is active and any particular mic button is still engaged."
+
 format = "Format"
 
 format_info_bar_tip = "Information about how the encoder is currently configured is displayed here."
@@ -524,7 +532,7 @@ good_quality_resample = "Good"
 
 green_phone_tip = "Mix voice over IP audio to the output stream."
 
-group = "Group"
+group = "Button group"
 
 group_action = " Group Controls "
 
@@ -595,6 +603,8 @@ initial_player_settings = "Player Settings At Startup"
 
 individual_controls = "Individual Controls"
 
+insert_attribute_or_colour_code = "Insert Attribute or Colour Code"
+
 interval = "Interval:"
 
 invert_left = "Invert left mic audio"
@@ -744,7 +754,15 @@ metadata = "Metadata: "
 
 metadata_checkbox_tip = "Choose the streams upon which you wish to reformat the metadata."
 
-metadata_entry_tip = "You can enter text to accompany the stream here, as well as incorporating the title of the currently playing track by including %s at the appropriate point."
+metadata_entry_tip = "You can enter text to accompany the stream here and can specify placemarkers %r %t %l %s for the artist, title, album, and songname respectively, or leave this text field blank to use the default metadata.\n\nSongname (%s) is derived from the filename in the absence of sufficient metadata, while the other placemarkers will use the fallback text to the right.\n\nWhen blank, Ogg streams will use the standard Vorbis tags and mp3 will use %s."
+
+metadata_format = "Format String"
+
+metadata_frame = " Metadata "
+
+metadata_fallback = "Fallback"
+
+metadata_fallback_tip = "The fallback text to use when %r %t %l metadata is unavailable. See the format string to the left."
 
 metadata_source_crossfader = "Crossfader"
 
@@ -760,7 +778,7 @@ metadata_source_right_deck = "Right Player"
 
 metadata_source_tip = "Select which Deck is responsible for the metadata on the stream."
 
-metadata_update_tip = "Update the metadata."
+metadata_update_tip = "Metadata normally updates only on song title changes but you can force an immediate update here."
 
 mic_agc = "Use AGC for mic audio processing (experimental)"
 
@@ -772,11 +790,15 @@ mic_compression_level_tip = "Controls whether to display a meter indicating the
 
 mic_in_phones = "Hearing your voice in your headphones (somewhat delayed) can be distracting which is why some users might want to turn this feature off."
 
+mic_off = "Deactivated"
+
 mic_simple = "Simple (low CPU drain)"
 
 mic_processed = "Full Signal Processing"
 
-mic_complexity_tip = "Use this to turn on microphone signal processing which may be all you need to make a cheap mic sound like a more expensive one or achieve a studio sound. The simple options on the other hand place less demand on the CPU and may be all you require."
+mic_stereo = "Partnered with Mic "
+
+mic_mode_tip = "The microphone mode."
 
 mic_off_tip = "Each time the microphone is turned off run the commands to the right."
 
@@ -848,6 +870,14 @@ mp4year = "Year"
 
 native = "Native"
 
+n_microphones = "Microphone audio channels*"
+
+n_streamers = "Simultaneous stream(s)"
+
+n_recorders = "Simultaneous recording(s)"
+
+n_feature_set_asterisk = "* Works only in Fully Featured mode"
+
 new_profile_body = """Profile '%s' does
 not currently exist.
 Would you like to create it?"""
@@ -904,7 +934,7 @@ normrise = "Rise"
 
 not_connected = "Not Connected"
 
-notag = "No Tag"
+notag = "Bad Tag"
 
 off = "Off"
 
@@ -920,6 +950,8 @@ open_mic_tip = "Allow microphone audio into the mix."
 
 other_mic_options = "General Mic Options"
 
+paired_frame_tip = "These controls are provided to obtain a decent match between the two microphones."
+
 pan = "Stereo Panning"
 
 pan_tip = """Stereo panning is the selection of where an audio source sits from left to right within the stereo mix.
@@ -988,7 +1020,9 @@ playlist_modes_tip = """This sets the playlist mode which defines player behavio
 
 'External' draws it's tracks from an external playlist or directory one at a time. Useful for when you want to stream massive playlists.
 
-'Alternate' causes the next track to be cued up before starting the opposite player. The crossfader is moved over."""
+'Alternate' causes the next track to be cued up before starting the opposite player. The crossfader is moved over.
+
+'Fade Over' will crossfade to the other player at the end of every track."""
 
 playlistfilter_all = "All file types"
 
@@ -1122,6 +1156,8 @@ red_phone_tip = "Mix voice over IP audio to the DJ only."
 
 refresh_jingles_tip = "Cause the playlist to be refreshed. This is for when items have been added or removed from the jingles playlist folder located at '~/.idjc/profiles/[active profile]/jingles'."
 
+relative_gain = "Relative Gain (dB)"
+
 remaining = "Remaining"
 
 remove = "Remove"
@@ -1130,6 +1166,8 @@ request_activate = "Activate"
 
 request_tab = "Request"
 
+requires_restart = " These settings take effect after restarting "
+
 resample_quality = "Quality"
 
 response = "Response"
@@ -1237,6 +1275,8 @@ sideline = "Sideline"
 
 sideline_tip = "A user interface clutter removal feature for unused or problematic streams."
 
+signal_matching = " Signal Matching "
+
 silence_killer = "End tracks early: those that have quiet endings"
 
 sharp = "Sharp"
@@ -1247,7 +1287,7 @@ shell_commands_tip = "Enter bash shell commands to run, separated by a semicolon
 
 show_microphone_meters = "Microphone Meters"
 
-song_placemarker = "Song name place marker = %s"
+song_placemarker = "Use %r %t %l %s for artist, title, album, songname."
 
 speed_variance = "Enable the main-player speed/pitch controls"
 
@@ -1489,6 +1529,14 @@ wet_voice_volume_tip = "This adjusts the volume level of the music that plays wh
 
 window_close = "Close"
 
+xchat_bold = "<b>Bold</b>"
+
+xchat_underline = "<u>Underline</u>"
+
+xchat_normal = "Normal"
+
+xchat_colours = "Colours"
+
 xchat_install_tip = "Having problems? Launch XChat, close XChat, press this button, launch XChat again."
 
 xchat_install = "Install The XChat Plugin"
