@@ -1,9 +1,9 @@
-#   ln_text.py: localisation support for IDJC (supercedes langheader.py)
-#   Copyright (C) 2008 Stephen Fairchild (s-fairchild@users.sourceforge.net)
+#   ln_text.py: localisation support for IDJC
+#   Copyright (C) 2010 Stephen Fairchild (s-fairchild@users.sourceforge.net)
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -71,9 +71,6 @@ class en_US(en_GB):
 class de_DE(en_GB):
    _load = True
    
-class nl_NL(en_GB):
-   _load = True
-
 def _set():               # choose which translation to use
    lev = os.getenv("LANG")
    try:
@@ -119,7 +116,7 @@ if __name__ == "__main__":
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
