@@ -543,27 +543,27 @@ class Prefs(gtk.Frame):
       hostlabel = self.rjustlabel(ln.prokyon3_hostname)
       table.attach(hostlabel, 0, 1, 0, 1, gtk.SHRINK | gtk.FILL)
       hostlabel.show()
-      self.prokhostname = DefaultEntry("localhost")
+      self.prokhostname = DefaultEntry("localhost", True)
       table.attach(self.prokhostname, 1, 4, 0, 1)
       self.prokhostname.show()
       userlabel = self.rjustlabel(ln.prokyon3_user)
       table.attach(userlabel, 0, 1, 1, 2, gtk.SHRINK | gtk.FILL)
       userlabel.show()
-      self.prokuser = DefaultEntry("prokyon")
+      self.prokuser = DefaultEntry("prokyon", True)
       self.prokuser.set_size_request(30, -1)
       table.attach(self.prokuser, 1, 2, 1, 2)
       self.prokuser.show()
       databaselabel = self.rjustlabel(ln.prokyon3_database)
       table.attach(databaselabel, 2, 3, 1, 2, gtk.SHRINK | gtk.FILL)
       databaselabel.show()
-      self.prokdatabase = DefaultEntry("prokyon")
+      self.prokdatabase = DefaultEntry("prokyon", True)
       self.prokdatabase.set_size_request(30, -1)
       table.attach(self.prokdatabase, 3, 4, 1, 2)
       self.prokdatabase.show()
       passwordlabel = self.rjustlabel(ln.prokyon3_password)
       table.attach(passwordlabel, 0, 1, 2, 3, gtk.SHRINK | gtk.FILL)
       passwordlabel.show()
-      self.prokpassword = DefaultEntry("prokyon")
+      self.prokpassword = DefaultEntry("prokyon", True)
       self.prokpassword.set_size_request(30, -1)
       self.prokpassword.set_visibility(False)
       table.attach(self.prokpassword, 1, 2, 2, 3)
